# PyDOE: An Experimental Design Package for Python

The `pyDOE` package is designed to help the **scientist, engineer,
statistician,** etc., to construct appropriate 
**experimental designs**.

!!! tip "Quick Start"
    All available designs can be accessed after a simple import statement:

    ```python
    >>> from pyDOE import *
    ```
